\name{BuildAgeTable}
\alias{BuildAgeTable}

\title{Builds a data.frame holding an age table}

\description{
  Builds a \code{data.frame} holding generic data for each cross-section.
There will be as many rows as the number of cross-sections.
The \code{data.frame} can be saved in a csv file through \code{\link{ExportFile}}.
}

\usage{
BuildAgeTable(RWdata, Tree.object)
}

\arguments{
	\item{RWdata}{a \code{data.frame} holding the set of ring-widths. It can be imported from a csv text file through \code{\link{ImportRW}}. In case of broadleaf trees, the age table must be computed on the ring-width set of the main stem.}
	\item{Tree.object}{a \code{data.frame} holding tree data. This object is easily created through \code{\link{BuildTreeObject}}.}
}

\seealso{\code{\link{ImportRW}}\code{\link{BuildTreeObject}}\code{\link{ExportFile}}}

\value{
Returns a \code{data.frame} holding cross-sections heights as rownames. 
For each cross-section, the first column holds the number of rings counted, the second column holds the its radius (as the sum of the full set of ring-widths), the third column holds its age (the tree age minus number of rings) when its tip got to the cross-section level. 
Tree age is computed as the number of rings on the lowest cross-section.
}

\author{Marco Bascietto}

\examples{
# Recall and attach RW data
data(Lei301)
attach(Lei301)

AgeTable1 <- BuildAgeTable(RW.1A, Tree.features.1)

detach(Lei301)
}

\keyword{attribute}



\eof
\name{BuildTreeObject}
\alias{BuildTreeObject}

\title{Builds a data.frame holding tree data}

\description{
  Builds a \code{data.frame} holding conversion coefficients and tree physical properties including. 
The creation of this object is a mandatory step before any call to \code{\link{StemAnalysis}} and to \code{\link{BuildAgeTable}}. It is passed as an argument to both the above functions.
}

\usage{
BuildTreeObject(tom = 1000000, tocm = 10000, vols = 1.0635, vols.ste = 0.0, basd = 0.51783, basd.ste = 0.04281, carb = 0.4577,carb.ste = 0.00243)
}

\arguments{
	\item{tom}{a numeric value holding the multiplicative coefficients to get to [m] from ring-width measures. This is used in \code{\link{StemAnalysis}}.}
	\item{tocm}{a numeric value holding the multiplicative coefficients to get to [cm] from ring-width measures. This is used in \code{\link{BuildAgeTable}}.}
	\item{vols}{a numeric value holding the multiplicative coefficients to get to fresh stem volume [m$^3$] from the computed volume.}
	\item{vols.ste}{a numeric value holding the standard error of the multiplicative coefficients to get to fresh stem volume [m$^3$] from the computed volume.}
	\item{basd}{a numeric value holding the wood basic density (\emph{i.e.} dry-matter wood weight over fresh wood volume).}
	\item{basd.ste}{a numeric value holding the standard error of wood basic density.}
	\item{carb}{a numeric value holding the amount of carbon stored in wood. It is expressed as a [0..1] number.}
	\item{carb.ste}{a numeric value holding the standard error of the amount of carbon stored in wood. It is expressed as a [0..1] number.}
}

\details{
Volume shrinks from wet wood to dry wood. if RWs are measured at room temperature and humidity, the computed volume must be expanded to fresh volume
If not measured, fetch the values for volume reduction in the literature (see below). If ring-widths are measured at room temperature and humidity, the tabled shrink coefficient has to be halved:
\emph{Picea abies} shrinkage coefficient from dry-matter to fresh volume is 1.127. (1.127-1)/2+1 becomes 1.0635. As a result, the computed volume of \emph{Picea abies} must be expanded of 6.35%
}

\seealso{\code{\link{StemAnalysis}}\code{\link{BuildAgeTable}}}

\note{
\code{BuildTreeObject} is just a wrapper for \code{data.frame}.
}

\references{
Nardi Berti R., La struttura anatomica del legno ed il riconoscimento dei legnami italiani di pi comune impiego, Contributi Scientifico-Pratici per una migliore conoscenza ed utilizzazione del legno, CNR 24 (1979) 117-155.\cr
in  Bascietto M., Scarascia-Mugnozza G., A collection of functions to determine annual tree Carbon increment via stem analysis, Annals of Forest Science (accepted)\cr
Giordano, G., Variazioni della densit del legno, in: Tecnologia del legno,UTET,Torino, Italy, pp. 832-869.
}

\author{Marco Bascietto}

\examples{
# Build a tree object
Tree.features.1 <- BuildTreeObject(vols=1.085, vols.ste=0.0, basd=0.5792, basd.ste=0.016, carb=0.4424,carb.ste=0.0011)
}

\keyword{attribute}


\eof
\name{ExportFile}
\alias{ExportFile}

\title{Export an object into a csv text file}

\description{
  Saves a csv text file containing the object passed as argument.
}

\usage{
ExportFile(SAdata, filename, ...)
}

\arguments{
	\item{...}{any argument to be passed to \code{write.table}}
	\item{SAdata}{a \code{data.frame} object to be saved to disk, may be either a stem-analysis, age table, or whatever \R object.}
	\item{filename}{a string giving the name of the file to save}
}

\details{
The function creates a csv text file. Csv files can easily be openend by any spreadsheet program.
}

\seealso{\code{\link{ImportRW}}}

\note{
\code{ExportFile} is just a wrapper for \code{write.table}.
}

\author{Marco Bascietto}

\keyword{file}


\eof
\name{ImportRW}
\alias{ImportRW}

\title{Import a ring-width file}

\description{
  Loads a csv text file containing the ring widths measured on tree cross-sections.
}

\usage{
ImportRW(filename)
}

\value{
  Returns a data.frame object holding the ring-widths. Calendar years are coded as row names, and can be accessed via \code{rownames()}. 
Cross-section heights along the stem are coded column names, they can be accessed via \code{colnames()} and converted to numeric values via \code{as.numeric()}.
}

\arguments{
	\item{filename}{a string giving the name of the file to load}
}

\details{
Ring-widths and their calendar years, as well the heights of the cross-sections they were measured from must be stored in a csv file. Ring-widths will be ordered in columns, from the lowest cross-section, to the highest (nearest to tree tip) cross-section. 
The first row will hold cross-sections heights (in m). 
The first column will hold the calendar years whose ring refer.
Csv files can be created through any spreadsheet program. As an example of what a future ring-width csv file might look in a spreadsheet consider the following:
\tabular{ccccc}{
	\tab	0.0	\tab	1.30	\tab	3.00	\tab	5.00	\cr
1990	\tab	1234	\tab		\tab		\tab		\cr
1991	\tab	1234	\tab		\tab		\tab		\cr
1992	\tab	1234	\tab	4232	\tab		\tab		\cr
1993	\tab	1234	\tab	4232	\tab	353	\tab		\cr
1994	\tab	1234	\tab	4232	\tab	353	\tab		\cr
1995	\tab	1234	\tab	4232	\tab	353	\tab		\cr
1996	\tab	1234	\tab	4232	\tab	353	\tab	3567	\cr
1997	\tab	1234	\tab	4232	\tab	353	\tab	3567	\cr
1998	\tab	1234	\tab	4232	\tab	353	\tab	3567	\cr
}
}

\seealso{\code{\link{ExportFile}}}

\note{
Decimals should be dot-separated.
}

\author{Marco Bascietto}

\keyword{file}


\eof
\name{IncrementPlot}
\alias{IncrementPlot}

\title{Draws a 4-plot graph of increments}

\description{
  An exploratory function that draws the lateral surface area, volume, dry-matter biomass, and carbon biomass increment over time.
}

\usage{
IncrementPlot(SA)
}

\arguments{
	\item{SA}{a \code{data.frame} holding the stem.analysis table.}
}

\details{
Lateral surface area increment is plotted as m$^2$/yr, volume increment as m$^3$/yr. The units of measure of increment of dry-matter biomass and carbon biomass depend on the unit of measure of the user-given wood-density values. Default unit of measures are Mg/yr (t/yr) for the former and MgC/yr (tC/yr) for the latter.
}

\seealso{\code{\link{StemAnalysis}}}

\author{Marco Bascietto}

\examples{
# Load and attach Lei301 data
data(Lei301)
attach(Lei301)

IncrementPlot(SA.1.a)

detach(Lei301)
}

\keyword{aplot}

\eof
\name{JoinBranchesToStem}
\alias{JoinBranchesToStem}

\title{Joins stem-analyses of large branches to stem-analysis of main stem}

\description{
  The complex architecture of broadleaf trees requires stem-analysis be computed on each large branch. To get an overall picture of tree increments the stem-analyses should be joined together.
}

\usage{
JoinBranchesToStem(RWdata, Tree.object, branches)
}

\arguments{
	\item{RWdata}{a \code{data.frame} holding the set of ring-widths. It can be imported from a csv text file through \code{\link{ImportRW}}.}
	\item{Tree.object}{a \code{data.frame} holding tree data. This object is easily created through \code{\link{BuildTreeObject}}.}
	\item{branches}{a list of \code{dataframe} objects holding the stem analysis of the stem and of each branch. The list can be created with the \code{c} function}
}

\details{

}

\seealso{\code{\link{StemAnalysis}}}

\note{
It should be noted that the current version of tReeglia does not support different tree data objects for the branches of trees. 
As a result, it is not possible to assign different volume reduction coefficients, densities, and carbon contents to individual branches of the tree.}

\author{Marco Bascietto}

\examples{
# Recall and attach RW data
data(Lei301)
attach(Lei301)

SA.1 <- JoinBranchesToStem(RW.1A, Tree.features.1, c(SA.1.a,SA.1.b))

detach(Lei301)
}

\keyword{manip}


\eof
\name{Lei301}
\alias{Lei301}

\docType{data}

\title{Ring widths and stem analyses of tree 1 of the Leindefelde 30 stand (Germany)}

\description{
  This data set gives the ring-widths measured on the cross-sections on the main stem and on its large branch for tree 1 of Leienfelde-30 stand.
Ring-widths are given in 1/1000 mm.
\code{Basic.density}, and \code{carbon.content} were measured on wood subsamples. The \code{volume.shrink} coefficient is taken from literature.
}

\usage{data(Lei301)}

\format{A list of data.frames from ring-width tables to stem analysis tables}

\source{Rings were dated and measured in October 2001, last ring is dated 2000, on a LINTAB 3 measuring device linked to the TSAP software program (Frank Rinn, Germany), by Marco Bascietto.
}

\references{Nardi Berti R., La struttura anatomica del legno ed il riconoscimento dei legnami italiani di pi comune impiego, Contributi Scientifico-Pratici per una migliore conoscenza ed utilizzazione del legno, CNR 24 (1979) 117-155.
in  Bascietto M., Scarascia-Mugnozza G., A collection of functions to determine annual tree Carbon increment via stem analysis, Ann. Sci. For. (accepted)
}

\author{Marco Bascietto}

\keyword{datasets}

\eof
\name{PoolPlot}
\alias{PoolPlot}

\title{Draws a 4-plot graph of pools}

\description{
  An exploratory function that draws the lateral surface area, volume, dry-matter biomass, and carbon biomass over time.
}

\usage{
PoolPlot(SA)
}

\arguments{
	\item{SA}{a \code{data.frame} holding the stem.analysis table.}
}

\details{
Lateral surface area is plotted as m$^2$, volume as m$^3$. The units of measure of dry-matter biomass and carbon biomass depend on the unit of measure of the user-given wood-density values. Default unit of measures are Mg (t) for the former and MgC (tC) for the latter.
}

\seealso{\code{\link{StemAnalysis}}}

\author{Marco Bascietto}

\examples{
# Load and attach Lei301 data
data(Lei301)
attach(Lei301)

PoolPlot(SA.1.a)
detach(Lei301)

}

\keyword{aplot}

\eof
\name{StemAnalysis}
\alias{StemAnalysis}

\title{Performs stem-analysis}

\description{
  Performs stem-analysis on ring-widths on stem cross-sections.
}

\usage{
StemAnalysis(RWdata, Tree.height=23.91, Tree.object)
}

\arguments{
	\item{RWdata}{a numeric value holding the multiplicative coefficients to get to [m] from ring-width measures. This is used in \code{\link{StemAnalysis}}.}
	\item{Tree.height}{a numeric value holding the height of the tree tip.}
	\item{Tree.object}{a \code{data.frame} holding tree data. This object is easily created through \code{\link{BuildTreeObject}}.}
}

\details{
The function first interpolates tree heights using the Carmean's algorithm, to yield past annual estimates of tree height.
Yealry log volumes are computed using the Smalian's formula (trapezium formula): \deqn{V=\frac{Gl+Gu}{2} (Hu-Hl)}{V=[(Gl+Gu)/2] * (Hu-Hl)} where Gl if basal area of the lower section, Gu is the basal area of the upper section, Hu is the height of the upper section, Hl is the height of the lower section.
The volume of the terminal cone is: \deqn{V=\frac{Gl}{3} (Htree-Hl)}{V=Gl/3*(Htree-Hl)} where Htree is the height of the tree.
Dry-matter biomass is computed by converting volume to weight by means of basic density. Carbon biomass is given by dry-matter biomass multiplied by wood carbon ratio.
The standard errors of volume coefficient, basic density and wood carbon ratio are combined using the standard formula of multiplicative error propagation for variables with uncorrelated variances:  \deqn{se\left(W_C\right)=W_C \cdot \sqrt{\left(\frac{se\left(S_V\right)}{S_V}\right)^2 + \left(\frac{se\left(D_W\right)}{D_W}\right)^2 + \left(\frac{se\left(R_C\right)}{R_C}\right)^2}}{se(Wc)=Wc[(se(Sv)/Sv)^2+(se(Dw)/Dw)^2+(se(Rc)/Rc)^2]^0.5} where se() is standard error, Wc is wood carbon biomass, Sv is the volume coefficient from fresh matter to mean water-content matter, Dw is wood basic density, and Rc is wood carbon ratio.
Yearly lateral surface area of the logs is: \deqn{L=\pi (Ru+Rl) (Hu-Hl)}{L=pi * (Ru+Rl) * (Hu-Hl)} where Ru and Rl are the radia on the upper and lower cross-sections, Hu and Hl are the heights of the upper and lower cross-sections.for the lateral surface area of logs
The lateral surface area of the terminal cone is: \deqn{L=\pi Rl \sqrt{Rl^2 + (Htree - Hu)}}{L=pi * Rl * (Rl^2 + (Htree-Hl))^0.5}

Volume and surface area increments are computed by difference of the consecutive stem volumes.
Dry-matter biomass is computed by multiplying volume by basic density, carbon biomass is obtained by multiplyng dry-matter biomass by carbon content.
}

\seealso{\code{\link{BuildTreeObject}}\code{\link{BuildAgeTable}}}

\references{
Carmean W.H., Site index curves for Upland Oaks in the Central States, Forest Science 18 (1972) 109-120.\cr
Fabbio G., Frattegiani M., Manetti M.C., Il metodo di analisi del fusto. Confronto tra cinque metodi di stima della relazione altezza-et, Annali dell'Istituto Sperimentale per la Selvicoltura, Arezzo 19 (1988) 117-154.\cr
Bascietto M., Scarascia-Mugnozza G., A collection of functions to determine annual tree Carbon increment via stem analysis, Annals of Forest Science (accepted).
}

\author{Marco Bascietto}

\examples{
# Recall and attach RW data
data(Lei301)
attach(Lei301)

# Perform stem analysis
SA.1.a <- StemAnalysis(RWdata = RW.1A, Tree.height=12.33, Tree.object=Tree.features.1)
SA.1.b <- StemAnalysis(RWdata = RW.1B, Tree.height=5.5, Tree.object=Tree.features.1)

detach(Lei301)
}

\keyword{manip}


\eof
\name{tReeglia-internal}
\alias{SuccEstimates}

\title{Internal tReeglia functions}

\description{
  Internal tReeglia functions.
}
\usage{
SuccEstimates(Vol.pool, Lateral.area, Tree.object)
}

\details{
  These are not to be called by the user.
}

\keyword{internal}

\eof
